@@ -1,6 +1,5 @@
-import numbers
 from math import ceil
-from typing import Any, Dict, List, Literal, Optional, Sequence, Tuple, Type, Union, overload
+from typing import Any, Dict, List, Literal, Optional, Sequence, Tuple, Type, TypeVar, Union, overload
 
 from requests import Response
 
@@ -10,9 +9,10 @@ from cognite.client.data_classes.contextualization import (
     DetectJobBundle,
     DiagramConvertResults,
     DiagramDetectResults,
+    FileReference,
     T_ContextualizationJob,
 )
-from cognite.client.exceptions import CogniteAPIError
+from cognite.client.exceptions import CogniteAPIError, CogniteMissingClientError
 from cognite.client.utils._auxiliary import to_camel_case
 
 DETECT_API_FILE_LIMIT = 50
@@ -20,6 +20,8 @@ DETECT_API_FILE_LIMIT = 50
 DETECT_API_STATUS_JOB_LIMIT = 1000
 # https://docs.cognite.com/api/playground/#tag/Engineering-diagrams/operation/diagramDetectMultipleResults
 
+_T = TypeVar("_T")
+
 
 class DiagramsAPI(APIClient):
     _RESOURCE_PATH = "/context/diagram"
@@ -55,28 +57,39 @@ class DiagramsAPI(APIClient):
         )
 
     @staticmethod
-    def _process_file_ids(ids: Union[Sequence[int], int, None], external_ids: Union[Sequence[str], str, None]) -> List:
+    def _list_from_instance_or_list(
+        instance_or_list: Union[Sequence[_T], _T, None], instance_type: Type[_T], error_message: str
+    ) -> Sequence[_T]:
+        if instance_or_list is None:
+            return []
+        if isinstance(instance_or_list, instance_type):
+            return [instance_or_list]
+        if isinstance(instance_or_list, list) and all(isinstance(x, instance_type) for x in instance_or_list):
+            return instance_or_list
+        raise TypeError(error_message)
+
+    @staticmethod
+    def _process_file_ids(
+        ids: Union[Sequence[int], int, None],
+        external_ids: Union[Sequence[str], str, None],
+        file_references: Union[Sequence[FileReference], FileReference, None],
+    ) -> List[Union[Dict[str, Union[int, str, Dict[str, int]]], Dict[str, str], Dict[str, int]]]:
+
+        ids = DiagramsAPI._list_from_instance_or_list(ids, int, "ids must be int or list of int")
+        external_ids = DiagramsAPI._list_from_instance_or_list(
+            external_ids, str, "external_ids must be str or list of str"
+        )
+        file_references = DiagramsAPI._list_from_instance_or_list(
+            file_references, FileReference, "file_references must be FileReference or list of FileReference"
+        )
         # Handle empty lists
-        if not external_ids and not ids:
-            raise ValueError("No ids specified")
-
-        if isinstance(ids, numbers.Integral):
-            ids = [ids]
-        elif isinstance(ids, list) or ids is None:
-            ids = ids or []
-        else:
-            raise TypeError("ids must be int or list of int")
-
-        if isinstance(external_ids, str):
-            external_ids = [external_ids]
-        elif isinstance(external_ids, list) or external_ids is None:
-            external_ids = external_ids or []
-        else:
-            raise TypeError("external_ids must be str or list of str")
+        if not (external_ids or ids or file_references):
+            raise ValueError("No ids, external ids or file references specified")
 
         id_objs = [{"fileId": id} for id in ids]
         external_id_objs = [{"fileExternalId": external_id} for external_id in external_ids]
-        return [*id_objs, *external_id_objs]
+        file_reference_objects = [file_reference.to_api_item() for file_reference in file_references]
+        return [*id_objs, *external_id_objs, *file_reference_objects]
 
     @overload
     def detect(
@@ -85,8 +98,9 @@ class DiagramsAPI(APIClient):
         search_field: str = "name",
         partial_match: bool = False,
         min_tokens: int = 2,
-        file_ids: Union[int, Sequence[int]] = None,
-        file_external_ids: Union[str, Sequence[str]] = None,
+        file_ids: Optional[Union[int, Sequence[int]]] = None,
+        file_external_ids: Optional[Union[str, Sequence[str]]] = None,
+        file_references: Union[List[FileReference], FileReference, None] = None,
         *,
         multiple_jobs: Literal[False],
     ) -> DiagramDetectResults:
@@ -99,8 +113,9 @@ class DiagramsAPI(APIClient):
         search_field: str = "name",
         partial_match: bool = False,
         min_tokens: int = 2,
-        file_ids: Union[int, Sequence[int]] = None,
-        file_external_ids: Union[str, Sequence[str]] = None,
+        file_ids: Optional[Union[int, Sequence[int]]] = None,
+        file_external_ids: Optional[Union[str, Sequence[str]]] = None,
+        file_references: Union[List[FileReference], FileReference, None] = None,
         *,
         multiple_jobs: Literal[True],
     ) -> Tuple[Optional[DetectJobBundle], List[Dict[str, Any]]]:
@@ -113,8 +128,9 @@ class DiagramsAPI(APIClient):
         search_field: str = "name",
         partial_match: bool = False,
         min_tokens: int = 2,
-        file_ids: Union[int, Sequence[int]] = None,
-        file_external_ids: Union[str, Sequence[str]] = None,
+        file_ids: Optional[Union[int, Sequence[int]]] = None,
+        file_external_ids: Optional[Union[str, Sequence[str]]] = None,
+        file_references: Union[List[FileReference], FileReference, None] = None,
     ) -> DiagramDetectResults:
         ...
 
@@ -124,15 +140,16 @@ class DiagramsAPI(APIClient):
         search_field: str = "name",
         partial_match: bool = False,
         min_tokens: int = 2,
-        file_ids: Union[int, Sequence[int]] = None,
-        file_external_ids: Union[str, Sequence[str]] = None,
+        file_ids: Optional[Union[int, Sequence[int]]] = None,
+        file_external_ids: Optional[Union[str, Sequence[str]]] = None,
+        file_references: Union[List[FileReference], FileReference, None] = None,
         *,
         multiple_jobs: bool = False,
     ) -> Union[DiagramDetectResults, Tuple[Optional[DetectJobBundle], List[Dict[str, Any]]]]:
 
         """Detect entities in a PNID.
         The results are not written to CDF.
-        Note: All users on this CDF subscription with assets read-all and files read-all capabilities in the project,
+        **Note**: All users on this CDF subscription with assets read-all and files read-all capabilities in the project,
         are able to access the data sent to this endpoint.
 
         Args:
@@ -142,6 +159,7 @@ class DiagramsAPI(APIClient):
             min_tokens (int): Minimal number of tokens a match must be based on
             file_ids (Sequence[int]): ID of the files, should already be uploaded in the same tenant.
             file_external_ids (Sequence[str]): File external ids.
+            file_references (Sequence[FileReference]): File references (id or external id) with page ranges.
         Keyword Args:
             multiple_jobs (bool): Enables you to publish multiple jobs. If True the method will return a tuple of DetectJobBundle and list
                 of potentially unposted files. If False it will return a single DiagramDetectResults. Defaults to False.
@@ -160,7 +178,7 @@ class DiagramsAPI(APIClient):
                     file_external_ids=["Test1"],
                 )
         """
-        items = self._process_file_ids(file_ids, file_external_ids)
+        items = self._process_file_ids(file_ids, file_external_ids, file_references)
         entities = [
             entity.dump(camel_case=True) if isinstance(entity, CogniteResource) else entity for entity in entities
         ]
@@ -209,6 +227,18 @@ class DiagramsAPI(APIClient):
             job_cls=DiagramDetectResults,
         )
 
+    def get_detect_jobs(self, job_ids: List[int]) -> List[DiagramDetectResults]:
+        if self._cognite_client is None:
+            raise CogniteMissingClientError
+        res = self._cognite_client.diagrams._post("/context/diagram/detect/status", json={"items": job_ids})
+        jobs = res.json()["items"]
+        return [
+            DiagramDetectResults._load_with_status(
+                data=job, cognite_client=self._cognite_client, status_path="/context/diagram/detect/"
+            )
+            for job in jobs
+        ]
+
     @staticmethod
     def _process_detect_job(detect_job: DiagramDetectResults) -> list:
         """process the result from detect job so it complies with diagram convert schema
@@ -219,6 +249,8 @@ class DiagramsAPI(APIClient):
         Returns:
             items: the format complies with diagram convert schema
         """
+        if any(item.get("page_range") is not None for item in detect_job.result["items"]):
+            raise NotImplementedError("Can not run convert on a detect job that used the page range feature")
         items = [
             {k: v for k, v in item.items() if k in {"annotations", "fileId"}} for item in detect_job.result["items"]
         ]  # diagram detect always return file id.
