@@ -3,6 +3,8 @@ from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
+from cognite.client.config import ClientConfig
+from cognite.client.credentials import OAuthClientCredentials
 from cognite.client.data_classes import (
     APIKey,
     APIKeyList,
@@ -26,9 +28,7 @@ if TYPE_CHECKING:
 
 
 class IAMAPI(APIClient):
-    def __init__(
-        self, config: utils._client_config.ClientConfig, api_version: str = None, cognite_client: "CogniteClient" = None
-    ) -> None:
+    def __init__(self, config: ClientConfig, api_version: str = None, cognite_client: "CogniteClient" = None) -> None:
         super().__init__(config, api_version=api_version, cognite_client=cognite_client)
         self.service_accounts = ServiceAccountsAPI(config, api_version=api_version, cognite_client=cognite_client)
         self.api_keys = APIKeysAPI(config, api_version=api_version, cognite_client=cognite_client)
@@ -386,9 +386,7 @@ class SessionsAPI(APIClient):
     _LIST_CLASS = SessionList
     _RESOURCE_PATH = "/sessions"
 
-    def __init__(
-        self, config: utils._client_config.ClientConfig, api_version: str = None, cognite_client: "CogniteClient" = None
-    ) -> None:
+    def __init__(self, config: ClientConfig, api_version: str = None, cognite_client: "CogniteClient" = None) -> None:
         super().__init__(config, api_version=api_version, cognite_client=cognite_client)
         self._LIST_LIMIT = 100
 
@@ -401,8 +399,10 @@ class SessionsAPI(APIClient):
         Returns:
             CreatedSession: The object with token inspection details.
         """
-        if client_credentials is None and self._config.token_client_id and self._config.token_client_secret:
-            client_credentials = ClientCredentials(self._config.token_client_id, self._config.token_client_secret)
+        if client_credentials is None and isinstance(self._config.credentials, OAuthClientCredentials):
+            client_credentials = ClientCredentials(
+                self._config.credentials.client_id, self._config.credentials.client_secret
+            )
 
         json = {"items": [client_credentials.dump(True) if client_credentials else {"tokenExchange": True}]}
 
