@@ -164,7 +164,13 @@ from cognite.client.data_classes.shared import (  # isort: skip
     TimestampRange,
 )
 
-from cognite.client.data_classes.datapoints import Datapoint, Datapoints, DatapointsList, DatapointsQuery  # isort: skip
+from cognite.client.data_classes.datapoints import (  # isort: skip
+    Datapoint,
+    Datapoints,
+    DatapointsList,
+    DatapointsArray,
+    DatapointsArrayList,
+)
 from cognite.client.data_classes.events import EndTimeFilter, Event, EventFilter, EventList, EventUpdate  # isort: skip
 from cognite.client.data_classes.login import LoginStatus  # isort: skip
 from cognite.client.data_classes.raw import Database, DatabaseList, Row, RowList, Table, TableList  # isort: skip
